<tr i="{{id}}" role="form"><td>
        <a href="javascript:void(0)" onclick="save_iface({{id}})">
            <span  class="glyphicon glyphicon-floppy-save"></span>
        </a></td>
{% for field in form %}
    {%if field.is_hidden%}
        {{field}}
    {%else%}
        <td {%if field.name == "machines"%}style="display:none"{%endif%} {%if field.errors%}class="has-error"{%endif%}>
                {{field}}
                {%for err in field.errors%}<span class="help-block">{{err}}</span>{%endfor%}
        </td>
    {%endif%}
{% endfor %}
</tr>
