{%extends 'base.html'%}
{%load forms%}
{%block breadcrum%}Bienvenid@{%endblock%}

{%block middle_col%}
    <div class="row">
            {%if form.errors%}
        <div class="col-md-12"><p class="text-error">Error de inicio de sesi&oacute;n</p></div>
    {%endif%}

        <form class="form-horizontal" action="{%url 'django.contrib.auth.views.login'%}" method="post">
            {% csrf_token %}
            <input type="hidden" name="next" value="{%url 'home'%}">
                <div class="col-md-10">
                        {% for field in form %}
                            {%bootstrap_field field "col-md-6" "col-lg-3 col-md-2" "col-lg-9 col-md-4" "form-control"%}
                        {% endfor %}
                </div>
                <button type="submit" class="btn btn-primary">Login</button>

        </form>

    </div>
{%endblock%}
{%block document_ready%}
        $("input [type=text]").addClass("form-control")
{%endblock%}
