{%load forms%}
{% csrf_token %}
{% for field in form %}
    {%if field.name == "machine"%}
        {%bootstrap_field field "hide" "col-lg-3 col-md-2" "col-lg-9 col-md-4"%}
    {%else%}
        {%bootstrap_field field "col-md-6" "col-lg-3 col-md-2" "col-lg-9 col-md-4"%}
    {%endif%}
{% endfor %}

