{%load forms%}
<div class="modal-dialog">
  <div class="modal-content">
    <div class="modal-header">
      <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
      <h4 class="modal-title">New conflicting IP</h4>
    </div>
    <div class="modal-body">
        <form id="fconflictingip">{% csrf_token %}
        {%for field in form%}
            {%bootstrap_field field "col-md-12" "col-lg-12 col-md-12" "col-lg-12 col-md-12"%}
        {%endfor%}
        </form>
    </div>
    <div class="modal-footer">
      <button type="button" class="btn btn-default" data-dismiss="modal" id="close_ci_modal_btn">Close</button>
      <button type="button" class="btn btn-primary" onclick="save_conflictingip()">Save changes</button>
    </div>
  </div><!-- /.modal-content -->
</div><!-- /.modal-dialog -->

