<!DOCTYPE html>
<html>
  <head>
    <link rel="icon" type="image/png" href="/static/pics/ib.png" />
    <title>IPAM</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">

    <link href="/static/css/bootstrap.min.css" rel="stylesheet" media="screen">
    <style>
        .list-panel:hover{
            background: grey;
            cursor: pointer;
        }
        #obj_id{
          display: none;
        }
        .hide{
          display:none;
        }
    </style>
    <!--[if lt IE 9]>
      <script src="/static/js/html5shiv.js"></script>
      <script src="./static/js/respond.min.js"></script>
    <![endif]-->
    <script>{%block script_head%}{%endblock%}</script>
  </head>
  <body>
    {% include "header.html" %}
    <ol class="breadcrumb">
        <li><a href="{%url 'home'%}">Home</a></li>
        {%block breadcrumb%}{%endblock%}
    </ol>
    <div class="row">
        <div class="col-md-2" id="left_col">
          {%if messages%}
            <div id="avisos">
                {% for message in messages %}
                  <div class="alert alert-{{message.tags}}" aria-hidden='true'>
                    <button type="button" class="close" data-dismiss="alert">&times;</button>
                    {{message}}
                  </div>
                {% endfor %}{%block avisos%}{%endblock%}
            </div>
          {%endif%}
        </div>
        <div class="col-md-8" id="middle_col">{%block middle_col %}{%endblock%}</div>
        <div class="col-md-2"><div class="row">{%block right_col%}{%endblock%}</div></div>
    </div>
    <script src="/static/js/jquery-1.10.2.min.js"></script>
    <script src="/static/js/bootstrap.min.js"></script>
    <script src="/static/js/utils.js"></script>
    <script>{%block script%}{%endblock%}</script>
    <script>$(document).ready(function(){
       load_dom_script_once("{%url 'conflicting_ip_js'%}")
      {%block document_ready%}{%endblock%}
      })</script>
  </body>
</html>
