<tr>
{% for field in form %}
    {%if field.is_hidden%}
        {{field}}
    {%else%}
        <td>
                {{ field }}
                {%for err in field.errors%}<span class="help-inline">{{err}}</span>{%endfor%}

        </td>

    {%endif%}

{% endfor %}
</tr>
