{%if field.is_hidden%}
    {{field}}
{%else%}
    <div class="form-group {{form_group_class}} {%if field.errors%}has-error{%endif%}">
        <label for="{{for_id}}" class="{{label_class}} control-label">{{field.label}}</label>
        <div class="{{inner_div_class}}">
            {{ field }}
        {%for err in field.errors%}<span class="help-block">{{err}}</span>{%endfor%}
        </div>
    </div>
{%endif%}
