{% load forms %}
{% if not field.is_hidden %}
{% with field.field.required as required %}
<label for="{{ id }}" {{ attrs|attrlist }}{% if required and not attrs.class %} class="required"{% endif %}>
    {{ contents }}
</label>
{% endwith %}
{% endif %}
