{%if paginator.has_other_pages%}
<div class="pagination span7 offset5">
    <ul>
    {% if paginator.has_previous %}
       <li><a href="javascript:void(0)" onclick="load_url('{{container}}', '{{url}}?page={{ paginator.previous_page_number }}')">Anterior</a></li>
       {%else%}
        <li><a href="javascript:void(0)" class="disabled">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</a></li>
    {% endif %}
        <li><span class="current">
        {{objeto|safe}} {{ paginator.number }} de {{ paginator.paginator.num_pages }}
    </span></li>
    {% if paginator.has_next %}
        <li><a href="javascript:void(0)" onclick="load_url('{{container}}', '{{url}}?page={{ paginator.next_page_number }}')">Siguiente</a></li>
        {%else%}
        <li><a href="javascript:void(0)" class="disabled">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</a></li>
    {% endif %}
    </ul>
</div>
{%endif%}
