{%load forms%}
{%if paginator.has_other_pages%}

<div class="col-md-11">
    <ul class="list-group">
    {% if paginator.has_previous %}
       <li class="list-group-item"><a href="{%url_add_query_element urll "page" paginator.previous_page_number %}">Anterior</a></li>
       {%else%}
        <li class="list-group-item"><a href="javascript:void(0)" class="disabled">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</a></li>
    {% endif %}
        <li class="list-group-item"><span class="current">
        {{objeto|safe}} {{ paginator.number }} de {{ paginator.paginator.num_pages }}
    </span></li>
    {% if paginator.has_next %}
        <li class="list-group-item"><a href="{%url_add_query_element urll "page" paginator.next_page_number %}">Siguiente</a></li>
        {%else%}
        <li class="list-group-item"><a href="javascript:void(0)" class="disabled">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</a></li>
    {% endif %}
    </ul>
</div>
{%endif%}
