{%if iface_id == None%}
{%include 'iface/list_by_machine_table_header.html'%}
{%endif%}
{%for iface in ifaces%}
    <tr i="{{iface.pk}}">
        <td>
            <a href="javascript:void(0)" onclick="del_iface({{iface.pk}})">
                <span  class="glyphicon glyphicon-trash"></span>
            </a>
            <a href="javascript:void(0)" onclick="edit_iface({{iface.pk}})">
                <span  class="glyphicon glyphicon-edit"></span>
            </a>
        </td>
        <td><a href="{%url 'iface' iface.pk%}">{{iface.ip}}</a></td><td>{{iface.dhcp}}</td><td>{{iface.vlan}}</td><td> {%  if iface.comments != None %}{{iface.comments|truncatechars:15}}  {% endif %}</td><td> {% for s in iface.services.all %} <a href="{% url 'service' s.id %}">{{s}}</a><br> {% endfor %}</td>
    </tr>
{%endfor%}
{%if iface_id == None%}
    {%include 'iface/list_by_machine_table_footer.html'%}
{%endif%}
