{% include "navbar.html" %}
<div class="row page-header">
    <div class="col-md-6">
        <a href="{%url 'home'%}">
            <img class="img-responsive" src="/static/pics/ib_logo.jpg" border="0">
        </a>
    </div>
    <div class="col-md-6">
        <div class="well pull-right"><h2 class="text-muted">IP Administration</h2>   {{user|cut:"AnonymousUser"}}
        {%if user.is_authenticated%}(<a href="{%url 'logout'%}">logout</a>){%endif%}</div>
    </div>
    <div class="col-md-1"></div>
</div>
